@@ -8,6 +8,7 @@ from pymongo import errors
 import datetime
 from typing import Tuple
 from util_hj3415 import utils
+from dart_hj3415 import opendart
 
 import logging
 
@@ -353,7 +354,8 @@ class Corps(Atlas):
     """
     COL_TITLE = ('c101', 'c104y', 'c104q', 'c106y', 'c106q', 'c108',
                  'c103손익계산서q', 'c103재무상태표q', 'c103현금흐름표q',
-                 'c103손익계산서y', 'c103재무상태표y', 'c103현금흐름표y', 'dart')
+                 'c103손익계산서y', 'c103재무상태표y', 'c103현금흐름표y',
+                 'dart', 'etc')
 
     @property
     def code(self):
@@ -521,6 +523,53 @@ class C101(Corps):
         return d
 
 
+class CEtc(Corps):
+    def __init__(self, client, code: str):
+        super(CEtc, self).__init__(client)
+        self.code = code
+        self.page = 'etc'
+        self.client[self.code][self.page].create_index('항목', unique=True)
+
+
+class CRefresh(CEtc):
+    # 한번 등록되면 리프레시 되는 횟수
+    COUNTER = 10
+
+    def __init__(self, client, code: str):
+        super(CRefresh, self).__init__(client, code)
+
+    def set_count(self, date: str) -> bool:
+        """
+        'etc' 컬렉션에 다음과 같이 카운트를 세팅하여 저장한다.
+        {'항목': 'refresh', 'count': 10, 'date': '20211010'}
+        """
+        if not utils.isYmd(date):
+            raise Exception(f'Invalid date format : {date}(%Y%m%d)')
+
+        print(f"Setting refresh doc ... 'count': {self.COUNTER}, 'date': {date}")
+        result = self.client[self.code][self.page].update_one(
+            {'항목': 'refresh'}, {"$set": {'count': self.COUNTER, 'date': date}}, upsert=True)
+        return result.acknowledged
+
+    def count_down(self) -> bool:
+        """
+        데이터베이스의 카운트를 확인하고 0이하면 삭제 0 이상이면 1을 줄인다.
+        """
+        doc = self.client[self.code][self.page].find_one({'항목': 'refresh'})
+        if doc is None or (doc['count'] <= 0):
+            self.initiate()
+            return False
+        else:
+            print(f"Counting down...{doc['count']} -> {doc['count']-1}")
+            self.client[self.code][self.page].update_one({'항목': 'refresh'}, {"$inc": {'count': - 1}})
+            return True
+
+    def initiate(self):
+        print("Initialting refresh doc ... {'count': 0, 'date': None}")
+        self.client[self.code][self.page].update_one(
+            {'항목': 'refresh'}, {"$set": {'count': 0, 'date': None}}, upsert=True)
+
+
 class CDart(Corps):
     """각 Code 별로 분류된 Dart 를 관리하는 클래스
     """
